@@ -1,7 +1,7 @@
 /* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
 /*
  * Almanah
- * Copyright (C) Philip Withnall 2008 <philip@tecnocode.co.uk>
+ * Copyright (C) Philip Withnall 2008-2009 <philip@tecnocode.co.uk>
  * 
  * Almanah is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,6 +23,7 @@
 #include <gconf/gconf-client.h>
 
 #include "storage-manager.h"
+#include "event-manager.h"
 
 #ifndef ALMANAH_MAIN_H
 #define ALMANAH_MAIN_H
@@ -35,19 +36,26 @@ G_BEGIN_DECLS
 
 typedef struct {
 	AlmanahStorageManager *storage_manager;
+	AlmanahEventManager *event_manager;
 	GConfClient *gconf_client;
+	GtkPrintSettings *print_settings;
+	GtkPageSetup *page_setup;
 
 	GtkWidget *main_window;
-	GtkWidget *add_link_dialog;
+	GtkWidget *add_definition_dialog;
 	GtkWidget *search_dialog;
+	GtkWidget *date_entry_dialog;
+	GtkWidget *definition_manager_window;
+	GtkWidget *import_dialog;
 #ifdef ENABLE_ENCRYPTION
 	GtkWidget *preferences_dialog;
 #endif /* ENABLE_ENCRYPTION */
 
 	gboolean debug;
+	gboolean import_mode;
 } Almanah;
 
-Almanah *almanah;
+extern Almanah *almanah;
 
 void almanah_quit (void);
 
